@@ -99,5 +99,5 @@
  * Since: 2019.3
  */
 #ifndef __GI_SCANNER__
-#define OSTREE_BUILT_FEATURES "gpgme ex-fsverity libarchive libmount systemd release p2p"
+#define OSTREE_BUILT_FEATURES "libcurl gpgme ex-fsverity libarchive libmount systemd release p2p"
 #endif
